//
//  MobileDaxhotelAppDelegate.m
//  MobileDaxhotel
//
//  Created by Raphael Schweikert on 11.06.08.
//  Copyright sabberworm 2008. All rights reserved.
//

#import "MobileDaxhotelAppDelegate.h"

@implementation MobileDaxhotelAppDelegate

static DataController *dataControllerInstance;

@synthesize mainWindow;
@synthesize detailView;
@synthesize loaderWindowController;
@synthesize mainWindowTableController;

- (void)applicationDidFinishLaunching:(UIApplication *)application {
    DAXHOTEL_DB_STATUS status = [[self dataController] status];
    [mainWindow makeKeyAndVisible];
    if(status == DAXHOTEL_DB_STATUS_EMPTY) {
        UIActionSheet *askSheet = [[UIActionSheet alloc] initWithTitle:NSLocalizedString(@"noDataInformation", @"noDataInformation") delegate:self cancelButtonTitle:NSLocalizedString(@"noDataButtonQuit", @"Quit") destructiveButtonTitle:NSLocalizedString(@"noDataButtonGetData", @"Get Data") otherButtonTitles:nil];
        [askSheet addButtonWithTitle:NSLocalizedString(@"noDataButtonGetLessData", @"Get Less Data")];
        [askSheet showInView: [application keyWindow]];
    } else if(status == DAXHOTEL_DB_STATUS_NO_CONTENT) {
        [loaderWindowController activate];
        [loaderWindowController loadData:[self dataController] status:status];
    } else {
        [self activateMainView];
    }
}
        
- (void)activateMainView {
    [mainWindow addSubview:mainWindowController.view];
    NSUInteger currentSeriesId = [[NSUserDefaults standardUserDefaults] integerForKey:@"currentSeriesId"]-1;
    NSUInteger currentEpisodeId = [[NSUserDefaults standardUserDefaults] integerForKey:@"currentEpisodeId"]-1;
    if(currentSeriesId != -1) {
        [mainWindowTableController pushSeriesControllerForSeries:[mainWindowTableController seriesWithSeriesId:currentSeriesId] animated:currentEpisodeId == -1];
    }
    if(currentEpisodeId != -1) {
        NSDictionary *episode = [[self dataController] episode:currentEpisodeId];
        [mainWindowTableController.navigationController pushViewController:detailView animated:YES];
        NSDictionary *seriesOfEpisode = [mainWindowTableController seriesWithSeriesId:[[episode valueForKey:@"series_id"] integerValue]];
        [detailView displayEpisode:[episode autorelease] ofSeries:seriesOfEpisode updateTintColor:(currentSeriesId == -1)];
    }
}


- (void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {
    if(buttonIndex == 1) {
        [[UIApplication sharedApplication] terminateWithSuccess];
    }
    [[self dataController] setInt:(buttonIndex == 0) forProperty:@"show_images_button"];
    [loaderWindowController activate];
    [loaderWindowController loadData:[self dataController] status:DAXHOTEL_DB_STATUS_EMPTY];
}

- (void)finishedLoading {
    [loaderWindowController deactivate];
    [self activateMainView];
}

- (DataController *)dataController {
    if(dataControllerInstance == nil) {
        dataControllerInstance = [[DataController alloc] initWithAppDelegate:self];
    }
    return dataControllerInstance;
}

- (void)applicationWillTerminate:(UIApplication *)application {
    NSUInteger currentSeriesId = -1;
    NSUInteger currentEpisodeId = -1;
    if(!loaderWindowController.isActive) {
        for(UIViewController *controller in mainWindowController.viewControllers) {
            if([controller isKindOfClass:[EpisodeSelectionTableController class]]) {
                currentSeriesId = [(EpisodeSelectionTableController *)controller currentSeriesId];
            } else if([controller isKindOfClass:[DetailViewController class]]) {
                currentEpisodeId = [(DetailViewController *)controller currentEpisodeId];
            }
        }
    }
        
    [[NSUserDefaults standardUserDefaults] setInteger:currentSeriesId+1 forKey:@"currentSeriesId"];
    [[NSUserDefaults standardUserDefaults] setInteger:currentEpisodeId+1 forKey:@"currentEpisodeId"];
}

- (void)applicationDidReceiveMemoryWarning:(UIApplication *)application {
    if(!loaderWindowController.isActive) {
        [dataControllerInstance release];
        dataControllerInstance=nil;
    }
}

- (void)dealloc {
    [mainWindow release];
    [loaderWindowController release];
    [detailView release];
    [dataControllerInstance release];
    [super dealloc];
}

@end
